##  Overview
The aggregation and linkage feature in the ServiceNow configuration enables you to import software records from ServiceNow as aggregated software fact sheets (a subtype of IT components) and automatically link these consolidated fact sheets to the reference catalog that provides lifecycle data. This eliminates the need to manually review and select software items that should be synced for obsolescence risk management initiatives.
With aggregation and linkage, all minor software versions, patches, and updates that share the same lifecycle (as per the SAP LeanIX reference catalog) are aggregated and imported as a single fact sheet into SAP LeanIX. During this process, these fact sheets are automatically linked to the reference catalog, enabling you to get relevant vendor lifecycle information for accurate obsolescence risk management without any manual interaction.
The following image illustrates how the aggregation and linkage feature works.
![Aggregation and Linkage of Software Items](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274dfddc7a441014a3a5e58dbbcc9e6b_LowRes.png)
Aggregation and Linkage of Software Records
